AgFormField class

Descriptor for a single form field.

Named AgFormField to avoid conflict with Flutter's FormField widget.

Constructors

AgFormField({required String name, required String label, required FormFieldType type, required bool isRequired, dynamic defaultValue, String? hint, List<String>? options})
const
AgFormField.fromJson(Map<String, dynamic> json)
factory

Properties

defaultValue → dynamic
final
hashCode int
The hash code for this object.
no setterinherited
hint String?
final
isRequired bool
final
label String
final
name String
final
options List<String>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type FormFieldType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited