ActivityDeltaEvent class final
Properties
- activityType → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- messageId → String
-
final
- patch → List
-
RFC 6902 JSON Patch operations applied to the activity content.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → int?
-
Unix timestamp in milliseconds, if provided by the backend.
finalinherited
- type → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited