Generic assistant provider — implement this against any backend.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
checkHealth(
) → Future< AssistantHealth> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
send(
{required String message, List< Map< history, Map<String, String> >String, dynamic> ? context}) → Future<AssistantResult> - Send a message and get a complete response.
-
stream(
{required String message, List< Map< history, Map<String, String> >String, dynamic> ? context}) → Stream<AssistantChunk> - Send a message and stream the response chunk by chunk.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited